| Title: | An Easier Access to Financial Accounts of the United States(Z.1) |
|---|---|
| Description: | Flow of funds are financial accounts that are provided by Federal Reserve quarterly. The package contains all datasets <https://www.federalreserve.gov/datadownload/Choose.aspx?rel=z1>, tables <https://www.federalreserve.gov/apps/fof/FOFTables.aspx> and descriptions <https://www.federalreserve.gov/apps/fof/Guide/z1_tables_description.pdf> with functions to understand series <https://www.federalreserve.gov/apps/fof/SeriesStructure.aspx> and explore them. |
| Authors: | Hamid Shafiezadeh [aut, cre] |
| Maintainer: | Hamid Shafiezadeh <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-06 08:48:20 UTC |
| Source: | https://github.com/cran/fedz1 |
all_tables_title() returns title of all tables. It is helpful to get familiar with available tables. Each table contains
a number of data set.
all_tables_title()all_tables_title()
A tibble of title of all tables
https://www.federalreserve.gov/apps/fof/FOFTables.aspx
all_tables_title()all_tables_title()
The function returns data series or tables. Due to CRAN package size requirements, the data is stored on github.
get_series(choice = c("series", "tables"))get_series(choice = c("series", "tables"))
choice |
can be "series" or "tables |
get_series() load entire series or tables. For example: get_series(choice="series")
series_data contains all series available in flow of funds and tables_data contains all tables and series
series or tables
date - Time-period
value - Observed-Value
SERIES_NAME - name of a series. There are more than twenty thousands series exist
CURRENCY - USD or NA. NA means series is percent or index
SERIES_PREFIX - Each prefix letters indicate the series type. see fedz1:::meaning_of_prefix()
UNIT - Currency, percent or index
UNIT_MULT - 1,1,000 or 1,000,000
short description _ description of the series
FREQ - A:annually data; Q:quarterly data
tname - name of a table
SERIES_NAME - name of a series. There are more than twenty thousands series exist
Description - Long Description of series
date - Time-period
value - Observed-Value
UNIT - Currency, percent or index
https://www.federalreserve.gov/datadownload/Choose.aspx?rel=z1
https://www.federalreserve.gov/apps/fof/FOFTables.aspx
meaning_of_prefix() returns definition of series. Each series start with two letters. Each prefix letters indicate the series type.
meaning_of_prefix(prefix)meaning_of_prefix(prefix)
prefix |
is SERIES_PREFIX. Value could be FA, FC, FG, FI, FL, FR, FS, FU, FV, LA, LM, PC. |
character for definition of series
https://www.federalreserve.gov/apps/fof/SeriesStructure.aspx
meaning_of_prefix("FL")meaning_of_prefix("FL")
Each prefix letters indicate the series type
mprefixmprefix
mprefix
A data frame with 12 rows and 2 columns:
prefix of series
meaning of a prefix
https://www.federalreserve.gov/apps/fof/SeriesStructure.aspx
Data is obtained from a web scraping from flow of funds website
prdsprds
prds
A data frame with 11,291 rows and 2 columns:
series name
description of the series
https://www.federalreserve.gov/datadownload/Choose.aspx?rel=z1
search_series() return all series with the search. For example: search_series("Real estate investment trusts")
search_series(series)search_series(series)
series |
is SERIES name |
A tibble of series
search_tables() return series associated with a table
search_tables(tables)search_tables(tables)
tables |
is table name |
A tibble of series in a table
search_tables("Nonfinancial Corporate Business")search_tables("Nonfinancial Corporate Business")
table_descr() return the definition of a table. Each table contains a number of data set.
table_descr(table_title)table_descr(table_title)
table_title |
is name of a single table or vector of multiple tables. You can obtain title of tables by |
character for definition of a table(s)
https://www.federalreserve.gov/apps/fof/Guide/z1_tables_description.pdf
table_descr('Credit Unions') table_descr(c('Net Capital Transfers',"Closed-End Funds"))table_descr('Credit Unions') table_descr(c('Net Capital Transfers',"Closed-End Funds"))
Data is obtained from a web scraping from Financial Accounts Guide
table_detailtable_detail
table_detail
A data frame with 198 rows and 3 columns:
title as shows on the source website
title of the table
code of each table as shows on the source website
https://www.federalreserve.gov/apps/fof/FOFTables.aspx